@@ -56,35 +56,35 @@ ggplot2::ggplot_add
 #' @examples
 #'
 #' # generate a null distribution
-#' null_dist <- gss %>%
+#' null_dist <- gss |>
 #'   # we're interested in the number of hours worked per week
-#'   specify(response = hours) %>%
+#'   specify(response = hours) |>
 #'   # hypothesizing that the mean is 40
-#'   hypothesize(null = "point", mu = 40) %>%
+#'   hypothesize(null = "point", mu = 40) |>
 #'   # generating data points for a null distribution
-#'   generate(reps = 1000, type = "bootstrap") %>%
+#'   generate(reps = 1000, type = "bootstrap") |>
 #'   # calculating a distribution of means
 #'   calculate(stat = "mean")
 #'
 #' # or a bootstrap distribution, omitting the hypothesize() step,
 #' # for use in confidence intervals
-#' boot_dist <- gss %>%
-#'   specify(response = hours) %>%
-#'   generate(reps = 1000, type = "bootstrap") %>%
+#' boot_dist <- gss |>
+#'   specify(response = hours) |>
+#'   generate(reps = 1000, type = "bootstrap") |>
 #'   calculate(stat = "mean")
 #'
 #' # we can easily plot the null distribution by piping into visualize
-#' null_dist %>%
+#' null_dist |>
 #'   visualize()
 #'
 #' # we can add layers to the plot as in ggplot, as well...
 #' # find the point estimate---mean number of hours worked per week
-#' point_estimate <- gss %>%
-#'   specify(response = hours) %>%
+#' point_estimate <- gss |>
+#'   specify(response = hours) |>
 #'   calculate(stat = "mean")
 #'
 #' # find a confidence interval around the point estimate
-#' ci <- boot_dist %>%
+#' ci <- boot_dist |>
 #'   get_confidence_interval(point_estimate = point_estimate,
 #'                           # at the 95% confidence level
 #'                           level = .95,
@@ -92,19 +92,19 @@ ggplot2::ggplot_add
 #'                           type = "se")
 #'
 #' # display a shading of the area beyond the p-value on the plot
-#' null_dist %>%
+#' null_dist |>
 #'   visualize() +
 #'   shade_p_value(obs_stat = point_estimate, direction = "two-sided")
 #'
 #' # ...or within the bounds of the confidence interval
-#' null_dist %>%
+#' null_dist |>
 #'   visualize() +
 #'   shade_confidence_interval(ci)
 #'
 #' # plot a theoretical sampling distribution by creating
 #' # a theory-based distribution with `assume()`
-#' sampling_dist <- gss %>%
-#'   specify(response = hours) %>%
+#' sampling_dist <- gss |>
+#'   specify(response = hours) |>
 #'   assume(distribution = "t")
 #'
 #' visualize(sampling_dist)
@@ -120,15 +120,15 @@ ggplot2::ggplot_add
 #' # to plot both a theory-based and simulation-based null distribution,
 #' # use a theorized statistic (i.e. one of t, z, F, or Chisq)
 #' # and supply the simulation-based null distribution
-#' null_dist_t <- gss %>%
-#'   specify(response = hours) %>%
-#'   hypothesize(null = "point", mu = 40) %>%
-#'   generate(reps = 1000, type = "bootstrap") %>%
+#' null_dist_t <- gss |>
+#'   specify(response = hours) |>
+#'   hypothesize(null = "point", mu = 40) |>
+#'   generate(reps = 1000, type = "bootstrap") |>
 #'   calculate(stat = "t")
 #'
-#' obs_stat <- gss %>%
-#'   specify(response = hours) %>%
-#'   hypothesize(null = "point", mu = 40) %>%
+#' obs_stat <- gss |>
+#'   specify(response = hours) |>
+#'   hypothesize(null = "point", mu = 40) |>
 #'   calculate(stat = "t")
 #'
 #' visualize(null_dist_t, method = "both")
@@ -141,10 +141,10 @@ ggplot2::ggplot_add
 #' # explanatory variables, use a `fit()`-based workflow
 #'
 #' # fit 1000 models with the `hours` variable permuted
-#' null_fits <- gss %>%
-#'  specify(hours ~ age + college) %>%
-#'  hypothesize(null = "independence") %>%
-#'  generate(reps = 1000, type = "permute") %>%
+#' null_fits <- gss |>
+#'  specify(hours ~ age + college) |>
+#'  hypothesize(null = "independence") |>
+#'  generate(reps = 1000, type = "permute") |>
 #'  fit()
 #'
 #' null_fits
@@ -159,10 +159,10 @@ ggplot2::ggplot_add
 #' library(ggplot2)
 #'
 #' # to add a ggplot2 theme to a `calculate()`-based visualization, use `+`
-#' null_dist %>% visualize() + theme_dark()
+#' null_dist |> visualize() + theme_dark()
 #'
 #' # to add a ggplot2 theme to a `fit()`-based visualization, use `&`
-#' null_fits %>% visualize() & theme_dark()
+#' null_fits |> visualize() & theme_dark()
 #' }
 #'
 #' # More in-depth explanation of how to use the infer package
@@ -170,19 +170,23 @@ ggplot2::ggplot_add
 #' vignette("infer")
 #' }
 #'
-#' @importFrom ggplot2 ggplot geom_histogram aes ggtitle
-#' @importFrom ggplot2 xlab ylab geom_vline geom_rect geom_bar
+#' @importFrom ggplot2 ggplot geom_histogram aes
+#' @importFrom ggplot2 geom_vline geom_rect geom_bar labs
 #' @importFrom stats dt qt df qf dnorm qnorm dchisq qchisq
 #' @export
-visualize <- function(data, bins = 15, method = "simulation",
-                      dens_color = "black",
-                      ...) {
+visualize <- function(
+  data,
+  bins = 15,
+  method = "simulation",
+  dens_color = "black",
+  ...
+) {
   if (inherits(data, "infer_dist")) {
     if (!missing(method) && method != "theoretical") {
-       cli_warn(c(
+      cli_warn(c(
         'Simulation-based visualization methods are not well-defined for \\
          `assume()` output; the `method` argument will be ignored.',
-         i = 'Set `method = "theoretical"` to silence this message.'
+        i = 'Set `method = "theoretical"` to silence this message.'
       ))
     }
 
@@ -207,12 +211,12 @@ visualize <- function(data, bins = 15, method = "simulation",
   dots <- check_dots_for_deprecated(list(...))
 
   if (is_fitted(data)) {
-    term_data <- data %>%
-      dplyr::rename(stat = estimate) %>%
-      dplyr::ungroup() %>%
-      dplyr::group_by(term) %>%
-      dplyr::group_split() %>%
-      purrr::map(copy_attrs, data) %>%
+    term_data <- data |>
+      dplyr::rename(stat = estimate) |>
+      dplyr::ungroup() |>
+      dplyr::group_by(term) |>
+      dplyr::group_split() |>
+      purrr::map(copy_attrs, data) |>
       purrr::map(copy_attrs, data, c("viz_method", "viz_bins"))
 
     plots <- purrr::map2(
@@ -252,9 +256,16 @@ visualize <- function(data, bins = 15, method = "simulation",
 visualise <- visualize
 
 
-visualize_term <- function(data, term, bins = 15, method = "simulation",
-                           dens_color = "black", dots, do_warn = TRUE,
-                           call = rlang::call2("visualize")) {
+visualize_term <- function(
+  data,
+  term,
+  bins = 15,
+  method = "simulation",
+  dens_color = "black",
+  dots,
+  do_warn = TRUE,
+  call = rlang::call2("visualize")
+) {
   data <- check_for_nan(data, "visualize")
   check_visualize_args(data, bins, method, dens_color, call = call)
   plot_data <- create_plot_data(data)
@@ -268,8 +279,15 @@ visualize_term <- function(data, term, bins = 15, method = "simulation",
 }
 
 check_dots_for_deprecated <- function(dots) {
-  dep_args <- c("obs_stat", "obs_stat_color", "pvalue_fill", "direction",
-                "endpoints", "endpoints_color", "ci_fill")
+  dep_args <- c(
+    "obs_stat",
+    "obs_stat_color",
+    "pvalue_fill",
+    "direction",
+    "endpoints",
+    "endpoints_color",
+    "ci_fill"
+  )
 
   if (any(dep_args %in% names(dots))) {
     bad_args <- dep_args[dep_args %in% names(dots)]
@@ -286,38 +304,44 @@ check_dots_for_deprecated <- function(dots) {
   list(NULL)
 }
 
-check_visualize_args <- function(data, bins, method, dens_color, call = caller_env()) {
+check_visualize_args <- function(
+  data,
+  bins,
+  method,
+  dens_color,
+  call = caller_env()
+) {
   check_is_distribution(data, "visualize")
   check_type(bins, is.numeric, call = call)
   check_type(method, is.character, call = call)
   check_type(dens_color, is.character, call = call)
 
   if (!(method %in% c("simulation", "theoretical", "both"))) {
-     cli_abort(
-       'Provide `method` with one of three options: `"theoretical"`, `"both"`, \\
+    cli_abort(
+      'Provide `method` with one of three options: `"theoretical"`, `"both"`, \\
         or `"simulation"`. `"simulation"` is the default for simulation-based \\
         null distributions, while `"theoretical"` is the only option for \\
         null distributions outputted by `assume()`.',
-       call = call
-     )
+      call = call
+    )
   }
 
   if (method == "both") {
     if (!("stat" %in% names(data))) {
-       cli_abort(
-         '`generate()` and `calculate()` are both required to be done prior \\
+      cli_abort(
+        '`generate()` and `calculate()` are both required to be done prior \\
           to `visualize(method = "both")`',
-         call = call
-       )
+        call = call
+      )
     }
 
     if (
       ("replicate" %in% names(data)) && (length(unique(data$replicate)) < 100)
     ) {
-       cli_warn(
+      cli_warn(
         "With only {length(unique(data$replicate))} replicates, it may be \\
          difficult to see the relationship between simulation and theory."
-       )
+      )
     }
   }
 
@@ -327,18 +351,18 @@ check_visualize_args <- function(data, bins, method, dens_color, call = caller_e
 # a function for checking arguments to functions that are added as layers
 # to visualize()d objects to make sure they weren't mistakenly piped
 check_for_piped_visualize <- function(..., call = caller_env()) {
-
   is_ggplot_output <- vapply(list(...), ggplot2::is_ggplot, logical(1))
 
   if (any(is_ggplot_output)) {
-
     called_function <- sys.call(-1)[[1]]
 
-    cli_abort(c(
-      "It looks like you piped the result of `visualize()` into \\
-       `{called_function}()` (using `%>%`) rather than adding the result of \\
+    cli_abort(
+      c(
+        "It looks like you piped the result of `visualize()` into \\
+       `{called_function}()` rather than adding the result of \\
        `{called_function}()` as a layer with `+`.",
-       i = "Consider changing `%>%` to `+`."),
+        i = "Consider changing `|>` (or `%>%`) to `+`."
+      ),
       call = call
     )
   }
@@ -353,47 +377,52 @@ impute_endpoints <- function(endpoints, plot = NULL, call = caller_env()) {
     x_lab <- x_axis_label(plot)
 
     res <-
-      endpoints %>%
-      dplyr::filter(term == x_lab) %>%
+      endpoints |>
+      dplyr::filter(term == x_lab) |>
       dplyr::select(-term)
 
     return(unlist(res))
   }
 
   if (is.vector(endpoints) && (length(endpoints) != 2)) {
-     cli_warn(
+    cli_warn(
       "Expecting `endpoints` to be a 1 x 2 data frame or 2 element vector. \\
        Using the first two entries as the `endpoints`."
-     )
+    )
     res <- endpoints[1:2]
   }
 
   if (is.data.frame(endpoints)) {
     if ((nrow(endpoints) != 1) || (ncol(endpoints) != 2)) {
-       cli_abort(
+      cli_abort(
         "Expecting `endpoints` to be a 1 x 2 data frame or 2 element vector.",
         call = call
-       )
+      )
     }
 
     res <- unlist(endpoints)
   }
 
-  res %>% copy_attrs(endpoints, attrs = c("se", "point_estimate"))
+  res |> copy_attrs(endpoints, attrs = c("se", "point_estimate"))
 }
 
-impute_obs_stat <- function(obs_stat, direction, endpoints, call = caller_env()) {
+impute_obs_stat <- function(
+  obs_stat,
+  direction,
+  endpoints,
+  call = caller_env()
+) {
   obs_stat <- check_obs_stat(obs_stat)
 
   if (
     !is.null(direction) &&
-    (is.null(obs_stat) + is.null(endpoints) != 1)
+      (is.null(obs_stat) + is.null(endpoints) != 1)
   ) {
-     cli_abort(
-       "Shading requires either `endpoints` values for a confidence interval \\
+    cli_abort(
+      "Shading requires either `endpoints` values for a confidence interval \\
         or the observed statistic `obs_stat` to be provided.",
-       call = call
-     )
+      call = call
+    )
   }
 
   obs_stat
@@ -420,11 +449,15 @@ simulation_layer <- function(data, dots = list(NULL)) {
       res <- list(
         do.call(
           ggplot2::stat_bin,
-          c(list(mapping = aes(x = stat),
-                 bins = bins,
-                 color = "white",
-                 breaks = bin_breaks),
-            dots)
+          c(
+            list(
+              mapping = aes(x = stat),
+              bins = bins,
+              color = "white",
+              breaks = bin_breaks
+            ),
+            dots
+          )
         )
       )
     } else {
@@ -440,12 +473,15 @@ simulation_layer <- function(data, dots = list(NULL)) {
     res <- list(
       do.call(
         ggplot2::stat_bin,
-        c(list(mapping = aes(x = stat, y = ggplot2::after_stat(density)),
-               bins = bins,
-               color = "white",
-               breaks = bin_breaks),
-          dots)
-
+        c(
+          list(
+            mapping = aes(x = stat, y = ggplot2::after_stat(density)),
+            bins = bins,
+            color = "white",
+            breaks = bin_breaks
+          ),
+          dots
+        )
       )
     )
   }
@@ -460,8 +496,14 @@ compute_bin_breaks <- function(data, bins) {
   c(g_tbl[["xmin"]][1], g_tbl[["xmax"]])
 }
 
-theoretical_layer <- function(data, dens_color, dots = list(NULL), do_warn = TRUE,
-                              mean_shift = 0, sd_shift = 1) {
+theoretical_layer <- function(
+  data,
+  dens_color,
+  dots = list(NULL),
+  do_warn = TRUE,
+  mean_shift = 0,
+  sd_shift = 1
+) {
   method <- get_viz_method(data)
 
   if (method == "simulation") {
@@ -475,20 +517,39 @@ theoretical_layer <- function(data, dens_color, dots = list(NULL), do_warn = TRU
   switch(
     theory_type,
     t = theory_curve(
-      method, dt, qt, list(df = attr(data, "distr_param")), dens_color,
-      mean_shift = mean_shift, sd_shift = sd_shift
+      method,
+      dt,
+      qt,
+      list(df = attr(data, "distr_param")),
+      dens_color,
+      mean_shift = mean_shift,
+      sd_shift = sd_shift
     ),
     `F` = theory_curve(
-      method, df, qf,
+      method,
+      df,
+      qf,
       list(
-        df1 = attr(data, "distr_param"), df2 = attr(data, "distr_param2")
+        df1 = attr(data, "distr_param"),
+        df2 = attr(data, "distr_param2")
       ),
       dens_color = dens_color
     ),
-    z = theory_curve(method, dnorm, qnorm, list(), dens_color,
-                     mean_shift = mean_shift, sd_shift = sd_shift),
+    z = theory_curve(
+      method,
+      dnorm,
+      qnorm,
+      list(),
+      dens_color,
+      mean_shift = mean_shift,
+      sd_shift = sd_shift
+    ),
     `Chi-Square` = theory_curve(
-      method, dchisq, qchisq, list(df = attr(data, "distr_param")), dens_color
+      method,
+      dchisq,
+      qchisq,
+      list(df = attr(data, "distr_param")),
+      dens_color
     )
   )
 }
@@ -507,37 +568,46 @@ warn_theoretical_layer <- function(data, do_warn = TRUE, call = caller_env()) {
 
   if (
     has_attr(data, "stat") &&
-    !(attr(data, "stat") %in% c("t", "z", "Chisq", "F"))
+      !(attr(data, "stat") %in% c("t", "z", "Chisq", "F"))
   ) {
     if (method == "theoretical") {
-       cli_warn(
+      cli_warn(
         "Your `calculate`d statistic and the theoretical distribution are on \\
          different scales. Displaying only the theoretical distribution."
-       )
+      )
     } else if (method == "both") {
-       cli_abort(
+      cli_abort(
         "Your `calculate`d statistic and the theoretical distribution are on \\
          different scales. Use a standardized `stat` instead.",
         call = call
-       )
+      )
     }
   }
 }
 
-theory_curve <- function(method, d_fun, q_fun, args_list, dens_color,
-                         mean_shift = 0, sd_shift = 1) {
-
+theory_curve <- function(
+  method,
+  d_fun,
+  q_fun,
+  args_list,
+  dens_color,
+  mean_shift = 0,
+  sd_shift = 1
+) {
   if (method == "theoretical") {
     d_fun_ <- shift_d_fun(d_fun, mean_shift, sd_shift)
 
     x_range <- (do.call(q_fun, c(p = list(c(0.001, 0.999)), args_list)) *
-                  sd_shift) +
+      sd_shift) +
       mean_shift
 
     res <- list(
       ggplot2::geom_path(
-        data = data.frame(x = x_range), mapping = aes(x = x),
-        stat = "function", fun = d_fun_, args = args_list,
+        data = data.frame(x = x_range),
+        mapping = aes(x = x),
+        stat = "function",
+        fun = d_fun_,
+        args = args_list,
         color = dens_color
       )
     )
@@ -545,7 +615,9 @@ theory_curve <- function(method, d_fun, q_fun, args_list, dens_color,
     res <- list(
       ggplot2::geom_path(
         mapping = aes(x = stat),
-        stat = "function", fun = d_fun, args = args_list,
+        stat = "function",
+        fun = d_fun,
+        args = args_list,
         color = dens_color
       )
     )
@@ -579,7 +651,7 @@ redraw_theory_layer <- function(plot, mean_shift, sd_shift) {
 }
 
 
-title_layer <- function(data, title_fn = ggplot2::ggtitle) {
+title_layer <- function(data, title_fn = function(x) labs(title = x)) {
   method <- get_viz_method(data)
   theory_type <- short_theory_type(data)
 
@@ -619,9 +691,9 @@ labels_layer <- function(data, term) {
   x_lab <- switch(method, simulation = "{term}", "{theory_type} stat")
   y_lab <- switch(method, simulation = "count", "density")
 
-  list(
-    xlab(glue(x_lab, .null = "NULL")),
-    ylab(glue(y_lab, .null = "NULL"))
+  labs(
+    x = glue(x_lab, .null = "NULL"),
+    y = glue(y_lab, .null = "NULL")
   )
 }
 
@@ -631,7 +703,11 @@ facet_layer <- function() {
   )
 }
 
-check_shade_confidence_interval_args <- function(color, fill, call = caller_env()) {
+check_shade_confidence_interval_args <- function(
+  color,
+  fill,
+  call = caller_env()
+) {
   check_type(color, is_color_string, "color string", call = call)
   if (!is.null(fill)) {
     check_type(fill, is_color_string, "color string", call = call)
@@ -652,7 +728,13 @@ short_theory_type <- function(x) {
     `Chi-Square` = c("Chi-square test of indep", "Chi-square Goodness of Fit")
   )
 
-  is_type <- vapply(theory_types, function(x) {theory_attr %in% x}, logical(1))
+  is_type <- vapply(
+    theory_types,
+    function(x) {
+      theory_attr %in% x
+    },
+    logical(1)
+  )
 
   names(theory_types)[which(is_type)[1]]
 }
@@ -667,14 +749,14 @@ get_viz_bins <- function(data) {
 
 #' @method ggplot_add infer_layer
 #' @export
-ggplot_add.infer_layer <- function(object, plot, object_name) {
+ggplot_add.infer_layer <- function(object, plot, ...) {
   # a method for the `+` operator for infer objects.
   # - "object to add" (arguments to the RHS of the `+`)
   # - plot is the existing plot (on the LHS of the `+`)
   # - object_name is the unevaluated call on the RHS of the `+`
   #
   # output is the actual output of the addition - this allows for
-  # a more %>%-esque programming style
+  # a more |>-esque programming style
   #
   # the biggest advantage this offers us is that we can
   # overwrite existing elements, i.e. subsetting into the patchwork,
@@ -687,8 +769,10 @@ ggplot_add.infer_layer <- function(object, plot, object_name) {
 
   # process object_name (shade_* call) ----------------------------------
   shade_fn <- attr(object, "fn")
-  shade_args <- attributes(object)[!names(attributes(object)) %in%
-                                     c("class", "fn")]
+  shade_args <- attributes(object)[
+    !names(attributes(object)) %in%
+      c("class", "fn")
+  ]
   shade_args["fill"] <- shade_args[["fill"]]
 
   # if a patchwork object, use a custom `infer_layer` `+.gg` method.
@@ -726,14 +810,16 @@ ggplot_add.infer_layer <- function(object, plot, object_name) {
 # extract the x axis label from a ggplot -- these are unique
 # ids for terms in visualize() workflows
 x_axis_label <- function(x) {
-  x %>% purrr::pluck("labels", "x")
+  x |> purrr::pluck("labels", "x")
 }
 
 create_plot_data <- function(data) {
   if (inherits(data, "infer_dist")) {
-    res <- tibble::tibble() %>%
-      copy_attrs(data,
-                 c("theory_type", "distr_param", "distr_param2", "viz_method"))
+    res <- tibble::tibble() |>
+      copy_attrs(
+        data,
+        c("theory_type", "distr_param", "distr_param2", "viz_method")
+      )
   } else {
     res <- data
   }
