@@ -1,12 +1,12 @@
-one_nonshift_mean <- mtcars_df %>% specify(response = mpg)
+one_nonshift_mean <- mtcars_df |> specify(response = mpg)
 
-one_nonshift_prop <- mtcars_df %>% specify(response = am, success = "1")
+one_nonshift_prop <- mtcars_df |> specify(response = am, success = "1")
 
-two_means_boot <- mtcars_df %>% specify(mpg ~ am)
+two_means_boot <- mtcars_df |> specify(mpg ~ am)
 
-two_props_boot <- mtcars_df %>% specify(am ~ vs, success = "1")
+two_props_boot <- mtcars_df |> specify(am ~ vs, success = "1")
 
-slope_boot <- mtcars_df %>% specify(mpg ~ hp)
+slope_boot <- mtcars_df |> specify(mpg ~ hp)
 
 test_that("auto `type` works (specify)", {
   expect_equal(attr(one_nonshift_mean, "type"), "bootstrap")
@@ -25,21 +25,13 @@ test_that("data argument", {
 
 test_that("response and explanatory arguments", {
   expect_snapshot(error = TRUE, specify(mtcars_df, response = blah))
-  expect_snapshot(error = TRUE,
-    specify(mtcars_df, response = "blah")
-  )
-  expect_snapshot(error = TRUE,
-    specify(mtcars_df, formula = mpg ~ blah)
-  )
+  expect_snapshot(error = TRUE, specify(mtcars_df, response = "blah"))
+  expect_snapshot(error = TRUE, specify(mtcars_df, formula = mpg ~ blah))
   expect_snapshot(error = TRUE, specify(mtcars_df, blah2 ~ cyl))
   expect_snapshot(error = TRUE, specify(mtcars_df))
   expect_snapshot(error = TRUE, specify(mtcars_df, formula = mpg ~ mpg))
-  expect_snapshot(error = TRUE,
-    specify(mtcars_df, formula = "mpg" ~ cyl)
-  )
-  expect_snapshot(error = TRUE,
-    specify(mtcars_df, formula = mpg ~ "cyl")
-  )
+  expect_snapshot(error = TRUE, specify(mtcars_df, formula = "mpg" ~ cyl))
+  expect_snapshot(error = TRUE, specify(mtcars_df, formula = mpg ~ "cyl"))
   expect_silent(specify(mtcars_df, formula = mpg ~ cyl))
 
   expect_snapshot(error = TRUE, specify(mtcars_df, formula = NULL ~ cyl))
@@ -47,12 +39,20 @@ test_that("response and explanatory arguments", {
 
 test_that("success argument", {
   expect_snapshot(error = TRUE, specify(mtcars_df, response = vs, success = 1))
-  expect_snapshot(error = TRUE, specify(mtcars_df, response = vs, success = "bogus"))
-  expect_snapshot(error = TRUE, specify(mtcars_df, response = mpg, success = "1"))
-  expect_snapshot(error = TRUE, specify(mtcars_df, response = cyl, success = "4"))
+  expect_snapshot(
+    error = TRUE,
+    specify(mtcars_df, response = vs, success = "bogus")
+  )
+  expect_snapshot(
+    error = TRUE,
+    specify(mtcars_df, response = mpg, success = "1")
+  )
+  expect_snapshot(
+    error = TRUE,
+    specify(mtcars_df, response = cyl, success = "4")
+  )
   # success not given
   expect_snapshot(error = TRUE, specify(mtcars_df, response = am))
-
 })
 
 test_that("sensible output", {
@@ -68,8 +68,8 @@ test_that("formula argument is a formula", {
   expect_snapshot(error = TRUE, specify(mtcars, am, success = "1"))
   expect_snapshot(error = TRUE, specify(mtcars, response = am, "1"))
   expect_silent({
-    mtcars %>%
-      dplyr::mutate(am = factor(am)) %>%
+    mtcars |>
+      dplyr::mutate(am = factor(am)) |>
       specify(response = am, success = "1")
   })
 })
@@ -84,33 +84,33 @@ test_that("specify doesn't have NSE issues (#256)", {
 })
 
 test_that("specify messages when dropping unused levels", {
-   expect_snapshot(
-    res_ <- gss %>%
-      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+  expect_snapshot(
+    res_ <- gss |>
+      dplyr::filter(partyid %in% c("rep", "dem")) |>
       specify(age ~ partyid)
   )
 
   expect_snapshot(
-    res_ <- gss %>%
-      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+    res_ <- gss |>
+      dplyr::filter(partyid %in% c("rep", "dem")) |>
       specify(partyid ~ age)
   )
 
   expect_snapshot(
-    res_ <- gss %>%
-      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+    res_ <- gss |>
+      dplyr::filter(partyid %in% c("rep", "dem")) |>
       specify(partyid ~ NULL)
   )
 
   expect_silent(
-    gss %>%
-      dplyr::filter(partyid %in% c("rep", "dem")) %>%
+    gss |>
+      dplyr::filter(partyid %in% c("rep", "dem")) |>
       specify(age ~ NULL)
   )
 })
 
 test_that("user can specify multiple explanatory variables", {
-  x <- gss %>% specify(hours ~ sex + college)
+  x <- gss |> specify(hours ~ sex + college)
 
   expect_true(inherits(x, "infer"))
   expect_true(inherits(explanatory_variable(x), "tbl_df"))
